                            % DISTURBANCE MODEL FOR BENCHMARK PATIENT SIMULATOR
                                    % CLARA IONESCU AND DANA COPOT
                                % GHENT UNIVERSITY, BELGIUM, JANUARY 2021

%when this program is used please cite the following: 
% An Open Source Patient Simulator for Design and Evaluation of Computer  Based Multiple Drug Dosing Control for Anesthetic and Hemodynamic Variables
% C. Ionescu, M. Neckebroek, Mi. Ghita and D. Copot
% IEEE Access; 2021; doi 10.1109/ACCESS.2021.3049880  
                                
          

%% Initialisation of disturbance models
%The disturbance is a signal tailored for surgical actions and is the
%stimulus which will be filtered through the nociceptor pathway.
%Additionally, there is a bolus from the anesthesiologist modelled.

%% Stimulus
[Bf,Af] = butter(4,0.2,'low'); %Butterworth filter
a=filtfilt(Bf,Af,ao); %Zero-phase forward and reverse digital IIR filtering
ab=filter(Bf,Af,ao); %One-dimensional digital fitler


%% Nociceptor pathway model
%Nociception model: 6th order complex conjugate pairs of poles and zeros
s = tf('s');
sus = ((s)^2+Z1*(s)+Z2)*((s)^2+Z3*(s)+Z4)*((s)^2+Z5*(s)+Z6);
jos = ((s)^2+P1*(s)+P2)*((s)^2+P3*(s)+P4)*((s)^2+P5*(s)+P6);
NOCI = K*sus/jos;
NOCImin = minreal(NOCI);
NOCIbal = balred(NOCI,1);
[numNOCI,denNOCI] = tfdata(NOCI,'v');
disto = lsim(NOCI,ao,1:size(ao,2)); %lsim: Simulate time response of dynamic systems to arbitrary inputs
dist = lsim(NOCI,a,1:size(a,2));
distb = lsim(NOCI,ab,1:size(ab,2));
